// A class to describe the trivy stages
class Trivy implements Serializable {
  private final Script script
  private final String trivyImage = "public.ecr.aws/aquasecurity/trivy:0.19.2"
  private final String scanners = "vuln,misconfig,secret,license"

  Trivy(Script script) {
    this.script = script
  }

  // Scan local project
  // https://trivy.dev/latest/docs/target/filesystem
  // https://trivy.dev/latest/docs/scanner/misconfiguration
  // https://trivy.dev/latest/docs/scanner/secret
  // https://trivy.dev/latest/docs/scanner/license
  void vuln() {
    script.stage() {
      script.docker.image(trivyImage)
                   .inside('-u root --entrypoint=""') {
        script.sh "trivy fs . --scanners ${scanners}"
      }
    }
  }

  // Generate SBOM in CycloneDX format
  // https://trivy.dev/latest/docs/supply-chain/sbom
  void sbom(String file = 'sbom-cyclonedx.json') {
    script.stage(file) {
      script.docker.image(trivyImage)
                   .inside('-u root --entrypoint=""') {
        // the SBOM can include the vulnerability list
        script.sh "trivy fs . --scanners vuln --format cyclonedx --output ${file}"
      }
    }
  }
}
